@@ -4,6 +4,7 @@ from datetime import timedelta, datetime
 
 from crispy_forms.bootstrap import StrictButton
 from date_offset.date_offset import DateOffset
+from dateutil.relativedelta import relativedelta
 from django.apps import apps
 from django.db import ProgrammingError, DataError
 from django.db.models import Q
@@ -16,9 +17,11 @@ from django_modals.forms import CrispyForm
 
 from advanced_report_builder.columns import ReportBuilderDateColumn
 from advanced_report_builder.exceptions import ReportError
-from advanced_report_builder.globals import NUMBER_FIELDS, ANNOTATION_VALUE_FUNCTIONS
+from advanced_report_builder.globals import NUMBER_FIELDS, ANNOTATION_VALUE_FUNCTIONS, ANNOTATION_VALUE_YEAR, \
+    ANNOTATION_VALUE_QUARTER, ANNOTATION_VALUE_WEEK, ANNOTATION_VALUE_DAY, ANNOTATION_VALUE_MONTH
 from advanced_report_builder.models import ReportType
-from advanced_report_builder.utils import split_slug, get_field_details, split_attr
+from advanced_report_builder.utils import split_slug, get_field_details, split_attr, get_report_builder_class
+from advanced_report_builder.variable_date import VariableDate
 from advanced_report_builder.views.report import ReportBase
 from advanced_report_builder.views.report_utils_mixin import ReportUtilsMixin
 from advanced_report_builder.views.targets.utils import get_target_value
@@ -128,8 +131,9 @@ class ChartBaseView(ReportBase, ReportUtilsMixin, TemplateView):
         field_name = self.chart_report.date_field
         if field_name is None:
             return
-        report_builder_class = getattr(base_model,
-                                       self.chart_report.report_type.report_builder_class_name, None)
+        report_builder_class = get_report_builder_class(model=base_model,
+                                                        report_type=self.chart_report.report_type)
+
         django_field, col_type_override, _, _ = get_field_details(base_model=base_model,
                                                                   field=field_name,
                                                                   report_builder_class=report_builder_class,
@@ -178,8 +182,8 @@ class ChartBaseView(ReportBase, ReportUtilsMixin, TemplateView):
             return fields
         chart_fields = self.chart_report.fields
 
-        report_builder_class = getattr(base_model,
-                                       self.chart_report.report_type.report_builder_class_name, None)
+        report_builder_class = get_report_builder_class(model=base_model,
+                                                        report_type=self.chart_report.report_type)
 
         for index, table_field in enumerate(chart_fields, 1):
             field = table_field['field']
@@ -302,6 +306,35 @@ class ChartBaseView(ReportBase, ReportUtilsMixin, TemplateView):
     def queries_menu(self):
         return []
 
+    @staticmethod
+    def get_period_divider(annotation_value_choice, start_date_type, end_date_type):
+        variable_date = VariableDate()
+        start_date_and_time, _, _ = variable_date.get_variable_dates(start_date_type)
+        _, end_date_and_time, _ = variable_date.get_variable_dates(end_date_type)
+        if annotation_value_choice == ANNOTATION_VALUE_YEAR:
+            divider = abs(end_date_and_time.year - start_date_and_time.year) + 1
+        elif annotation_value_choice == ANNOTATION_VALUE_QUARTER:
+            delta = relativedelta(end_date_and_time, start_date_and_time)
+            divider = delta.years * 4 + delta.months // 3
+        elif annotation_value_choice == ANNOTATION_VALUE_MONTH:
+            rdate = relativedelta(end_date_and_time, start_date_and_time)
+            divider = 0
+            if rdate.years is not None and abs(rdate.years) > 0:
+                divider += abs(rdate.years) * 12
+            if rdate.months is not None and abs(rdate.months) > 0:
+                divider += rdate.months
+            if rdate.days is not None and abs(rdate.days) > 0:
+                divider += 1
+        elif annotation_value_choice == ANNOTATION_VALUE_WEEK:
+            monday1 = (start_date_and_time - timedelta(days=start_date_and_time.weekday()))
+            monday2 = (end_date_and_time - timedelta(days=end_date_and_time.weekday()))
+            divider = int((monday2 - monday1).days / 7)
+        elif annotation_value_choice == ANNOTATION_VALUE_DAY:
+            divider = (end_date_and_time - start_date_and_time).days
+        else:
+            raise ReportError('unknown annotation_value_choice')
+        return divider
+
 
 class ChartBaseFieldForm(CrispyForm):
     cancel_class = 'btn-secondary modal-cancel'
@@ -327,24 +360,28 @@ class ChartBaseFieldForm(CrispyForm):
 
         report_type = get_object_or_404(ReportType, pk=self.slug['report_type_id'])
         base_model = report_type.content_type.model_class()
-        report_builder_class = getattr(base_model,
-                                       report_type.report_builder_class_name, None)
+
+        report_builder_class = get_report_builder_class(model=base_model,
+                                                        report_type=report_type)
+
         self.django_field, self.col_type_override, _, _ = get_field_details(base_model=base_model,
                                                                             field=data['field'],
                                                                             report_builder_class=report_builder_class)
 
         return report_type, base_model
 
-    def _get_query_builder_foreign_key_fields(self, base_model, report_builder_fields, fields,
+    def _get_query_builder_foreign_key_fields(self, base_model, report_builder_class, fields,
                                               prefix='', title_prefix='', previous_base_model=None):
-        for include_field, include in report_builder_fields.includes.items():
+        for include_field, include in report_builder_class.includes.items():
             app_label, model, report_builder_fields_str = include['model'].split('.')
             new_model = apps.get_model(app_label, model)
             if new_model != previous_base_model:
-                new_report_builder_fields = getattr(new_model, report_builder_fields_str, None)
+                new_report_builder_class = get_report_builder_class(model=new_model,
+                                                                    class_name=report_builder_fields_str)
+
                 fields.append((prefix + include_field, title_prefix + include['title']))
                 self._get_query_builder_foreign_key_fields(base_model=new_model,
-                                                           report_builder_fields=new_report_builder_fields,
+                                                           report_builder_class=new_report_builder_class,
                                                            fields=fields,
                                                            prefix=f"{prefix}{include_field}__",
                                                            title_prefix=f"{title_prefix}{include['title']} --> ",
