@@ -3,6 +3,8 @@ import json
 import operator
 from functools import reduce
 
+from django.db.models import FloatField, ExpressionWrapper
+from django.db.models.functions import NullIf
 from django_datatables.columns import CurrencyPenceColumn, CurrencyColumn
 
 from advanced_report_builder.columns import ReportBuilderCurrencyPenceColumn, ReportBuilderCurrencyColumn, \
@@ -18,7 +20,7 @@ class ReportUtilsMixin(FilterQueryMixin):
 
     def get_number_field(self, annotations_type, index, table_field, data_attr, fields, col_type_override,
                          extra_filter=None, title_suffix='', multiple_index=0, decimal_places=None,
-                         convert_currency_fields=False, totals=None):
+                         convert_currency_fields=False, totals=None, divider=None):
         field_name = table_field['field']
         css_class = None
         annotation_filter = None
@@ -30,7 +32,11 @@ class ReportUtilsMixin(FilterQueryMixin):
                 annotation_filter = self.process_filters(search_filter_data=_filter, extra_filter=extra_filter)
             elif extra_filter:
                 annotation_filter = reduce(operator.and_, [extra_filter])
-        title = title_suffix + ' ' + table_field.get('title')
+
+        if int(data_attr.get('display_heading', 1)) == 0:
+            title = ''
+        else:
+            title = title_suffix + ' ' + table_field.get('title')
         if col_type_override:
             col_type_override.table = None
             field = copy.deepcopy(col_type_override)
@@ -71,6 +77,8 @@ class ReportUtilsMixin(FilterQueryMixin):
                     function = function_type(raw_field_name, filter=annotation_filter)
                 else:
                     function = function_type(raw_field_name)
+                if divider:
+                    function = ExpressionWrapper(function / NullIf(divider, 0), output_field=FloatField())
                 if self.use_annotations:
                     number_function_kwargs['annotations'] = {new_field_name: function}
                 else:
@@ -92,6 +100,8 @@ class ReportUtilsMixin(FilterQueryMixin):
                         function = function_type(raw_field_name, filter=annotation_filter)
                     else:
                         function = function_type(raw_field_name)
+                    if divider:
+                        function = ExpressionWrapper(function / NullIf(divider, 0), output_field=FloatField())
                     if self.use_annotations:
                         field.annotations = {new_field_name: function}
                     else:
@@ -120,6 +130,7 @@ class ReportUtilsMixin(FilterQueryMixin):
                     function = function_type(field_name, filter=annotation_filter)
                 else:
                     function = function_type(field_name)
+
                 if self.use_annotations:
                     number_function_kwargs['annotations'] = {new_field_name: function}
                 else:
